pub struct InvalidItemReason {
pub invalid_item_reason_code: InvalidItemReasonCode,
pub description: String,
}Expand description
InvalidItemReason : The reason that the item is invalid for return.
Fields
invalid_item_reason_code: InvalidItemReasonCodedescription: StringA human readable description of the invalid item reason code.
Implementations
sourceimpl InvalidItemReason
impl InvalidItemReason
sourcepub fn new(
invalid_item_reason_code: InvalidItemReasonCode,
description: String
) -> InvalidItemReason
pub fn new(
invalid_item_reason_code: InvalidItemReasonCode,
description: String
) -> InvalidItemReason
The reason that the item is invalid for return.